sshagent

package
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2026 License: MIT Imports: 18 Imported by: 0

Documentation

Overview

Package sshagent implements a provider that derives a 32-byte secret by having the SSH agent sign a deterministic challenge. The secret is the HKDF-SHA256 of the resulting Ed25519 signature.

Only Ed25519 keys are supported because their signatures are deterministic (same key + same message = same signature), which is required for reliable key reconstruction.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AgentKeyInfo

type AgentKeyInfo struct {
	Fingerprint string
	Comment     string
}

AgentKeyInfo holds metadata about an Ed25519 key in the agent.

func ListEd25519Keys

func ListEd25519Keys() ([]AgentKeyInfo, error)

ListEd25519Keys connects to the SSH agent and returns Ed25519 keys.

type SSHAgent

type SSHAgent struct{}

SSHAgent is the SSH agent provider.

func (*SSHAgent) Derive

func (s *SSHAgent) Derive(ctx context.Context, params map[string]string) ([]byte, error)

func (*SSHAgent) Description

func (s *SSHAgent) Description() string

func (*SSHAgent) Enroll

func (s *SSHAgent) Enroll(ctx context.Context, id string) (*provider.EnrollResult, error)

func (*SSHAgent) InteractiveDerive

func (s *SSHAgent) InteractiveDerive() bool

func (*SSHAgent) Type

func (s *SSHAgent) Type() string

Jump to